@@ -1,13 +1,12 @@
 package Image::ButtonMaker;
 
-our $VERSION  = '0.1.4';
+our $VERSION  = 0.1;
 
 use strict;
 use utf8;
 use Image::ButtonMaker::ButtonClass;
 use Image::ButtonMaker::ClassContainer;
 use Image::ButtonMaker::Lexicon;
-use locale;
 
 my @default = (
                image_dirs   => undef,
@@ -57,17 +56,14 @@ sub replace_properties {
                 if(length($replace)) {
                     $properties->{$key} = $replace;
                 } else {
-                    print STDERR "WARNING: lexicon lookup($lang_id, $value) returned nothing\n";
+                    print "Lexicon warning: lookup($lang_id, $value) returned nothing\n";
                 }
             }
         }
 
         #### Path replacements ################################
         elsif($key eq 'TextFont') {
-            my $filename = $self->find_font_file($value);
-            print STDERR "WARNING: could not find file for font: $value"
-              unless(defined $filename);
-            $properties->{$key} = $filename;
+            $properties->{$key} = $self->find_font_file($value);
         }
         elsif($key eq 'CanvasTemplateImg') {
             $properties->{$key} = $self->find_image_file($value);
@@ -84,19 +80,18 @@ sub read_classfile {
     my $self      = shift;
     while(my $classfile = shift) {
         my $classcontainer = $self->{classes};
-
+        
         my $classList  = do $classfile;
         die "Error reading classfile $classfile: $@" if($@);
         die "Error reading classfile $classfile: $!" if($!);
-
+        
         foreach my $class (@$classList) {
             $self->replace_properties($class);
             my $class_obj = Image::ButtonMaker::ButtonClass->new(@$class);
-            die "CLASSERROR ($Image::ButtonMaker::ButtonClass::error) $Image::ButtonMaker::ButtonClass::errorstr"
-              unless($class_obj);
+            die "CLASSERR" unless($class_obj);
             $classcontainer->add_class($class_obj);
         }
-
+        
         die "Could not read classfile $classfile because:\n $@" if($@);
     }
 
@@ -117,7 +112,7 @@ sub read_buttonfile {
 
     foreach my $button (@$buttonList) {
         $self->replace_properties($button);
-        my $button_obj = Image::ButtonMaker::Button->new(@$button,
+        my $button_obj = Image::ButtonMaker::Button->new(@$button, 
                                                    classcontainer => $classcontainer);
         die "BUTTERR $Image::ButtonMaker::Button::errorstr" unless($button_obj);
 
@@ -219,7 +214,7 @@ sub find_font_file {
     my $self = shift;
     my $file = shift;
     my $dirs = $self->{font_dirs};
-
+    
     foreach my $d (@$dirs) {
         return "$d/$file" if(-f "$d/$file");
     }
